pitchtools.diatonic_pitch_name_to_chromatic_pitch_class_name
============================================================

.. autofunction:: abjad.tools.pitchtools.diatonic_pitch_name_to_chromatic_pitch_class_name.diatonic_pitch_name_to_chromatic_pitch_class_name
